@@ -117,7 +117,33 @@ enum ldns_enum_status {
 	LDNS_STATUS_DANE_TLSA_DID_NOT_MATCH,
 	LDNS_STATUS_DANE_NON_CA_CERTIFICATE,
 	LDNS_STATUS_DANE_PKIX_DID_NOT_VALIDATE,
-	LDNS_STATUS_DANE_PKIX_NO_SELF_SIGNED_TRUST_ANCHOR
+	LDNS_STATUS_DANE_PKIX_NO_SELF_SIGNED_TRUST_ANCHOR,
+	LDNS_STATUS_EXISTS_ERR,
+	LDNS_STATUS_INVALID_ILNP64,
+	LDNS_STATUS_INVALID_EUI48,
+	LDNS_STATUS_INVALID_EUI64,
+	LDNS_STATUS_WIRE_RDATA_ERR,
+	LDNS_STATUS_INVALID_TAG,
+	LDNS_STATUS_TYPE_NOT_IN_BITMAP,
+	LDNS_STATUS_INVALID_RDF_TYPE,
+	LDNS_STATUS_RDATA_OVERFLOW,
+	LDNS_STATUS_SYNTAX_SUPERFLUOUS_TEXT_ERR,
+	LDNS_STATUS_NSEC3_DOMAINNAME_OVERFLOW,
+	LDNS_STATUS_DANE_NEED_OPENSSL_GE_1_1_FOR_DANE_TA,
+	LDNS_STATUS_ZONEMD_DOUBLE_OCCURRENCE,
+	LDNS_STATUS_ZONEMD_UNKNOWN_SCHEME,
+	LDNS_STATUS_ZONEMD_UNKNOWN_HASH,
+	LDNS_STATUS_ZONEMD_INVALID_SOA,
+	LDNS_STATUS_NO_ZONEMD,
+	LDNS_STATUS_NO_VALID_ZONEMD,
+	LDNS_STATUS_SYNTAX_SVCPARAM_KEY_ERR,
+	LDNS_STATUS_SYNTAX_SVCPARAM_VALUE_ERR,
+	LDNS_STATUS_RESERVED_SVCPARAM_KEY,
+	LDNS_STATUS_NO_SVCPARAM_VALUE_EXPECTED,
+	LDNS_STATUS_SVCPARAM_KEY_MORE_THAN_ONCE,
+	LDNS_STATUS_INVALID_SVCPARAM_VALUE,
+	LDNS_STATUS_NOT_EDE,
+	LDNS_STATUS_EDE_OPTION_MALFORMED
 };
 typedef enum ldns_enum_status ldns_status;
 
